import os
from distutils.core import setup

setup_pars = {
    "packages" : [
        'csst_dfs_api_cluster',
        'csst_dfs_api_cluster.common',
        'csst_dfs_api_cluster.cpic',
        'csst_dfs_api_cluster.facility',
        'csst_dfs_api_cluster.hstdm',
        'csst_dfs_api_cluster.ifs',
        'csst_dfs_api_cluster.mbi',
        'csst_dfs_api_cluster.mci',
        'csst_dfs_api_cluster.sls',
    ],
    "package_dir" : {
        'csst_dfs_api_cluster' : 'csst_dfs_api_cluster',
        'csst_dfs_api_cluster.common' : 'csst_dfs_api_cluster/common',
        'csst_dfs_api_cluster.cpic' : 'csst_dfs_api_cluster/cpic',
        'csst_dfs_api_cluster.facility' : 'csst_dfs_api_cluster/facility',
        'csst_dfs_api_cluster.hstdm' : 'csst_dfs_api_cluster/hstdm',
        'csst_dfs_api_cluster.ifs' : 'csst_dfs_api_cluster/ifs',
        'csst_dfs_api_cluster.mbi' : 'csst_dfs_api_cluster/mbi',
        'csst_dfs_api_cluster.mci' : 'csst_dfs_api_cluster/mci',
        'csst_dfs_api_cluster.sls' : 'csst_dfs_api_cluster/sls',
    },
}
def requirements():
    with open("requirements.txt", "r") as f:
        return [
            req.strip()
            for req in f.readlines()
            if not req.startswith("#") and req.__contains__("==")
        ]

def version():
    __version = {}
    version_path = os.path.join(os.path.dirname(__file__), "csst_dfs_api_cluster", "version.py")
    with open(version_path, "r") as file:
        exec(file.read(), __version)
    return __version["__version__"]

setup(
    name="csst_dfs_api_cluster",
    version=version(),
    description="API's to access CSST Data Flow System (DFS)",
    long_description=open('README.md').read(),
    license="MIT",
    python_requires=">=3.7",
    install_requires=requirements(),
    zip_safe=False,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Scientific/Engineering :: Physics",
        "Topic :: Scientific/Engineering :: Astronomy",

    ],
    include_package_data=False,
    project_urls={
        'Source': 'https://csst-tb.bao.ac.cn/code/csst-dfs/csst-dfs-api-cluster',
    },
    **setup_pars
)
